@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: lwgeodetic.c 11535 2013-06-07 17:39:43Z pramsey $
+ * $Id: lwgeodetic.c 12674 2014-06-27 07:34:45Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * Copyright 2009 Paul Ramsey <pramsey@cleverelephant.ca>
@@ -443,10 +443,10 @@ static void vector_scale(POINT3D *n, double scale)
 	return;
 }
 
-static inline double vector_magnitude(const POINT3D* v)
-{
-	return sqrt(v->x*v->x + v->y*v->y + v->z*v->z);
-}
+// static inline double vector_magnitude(const POINT3D* v)
+// {
+// 	return sqrt(v->x*v->x + v->y*v->y + v->z*v->z);
+// }
 
 /**
 * Angle between two unit vectors
@@ -1419,7 +1419,22 @@ int edge_calculate_gbox(const POINT3D *A1, const POINT3D *A2, GBOX *gbox)
 	return LW_SUCCESS;
 }
 
-
+void lwpoly_pt_outside(const LWPOLY *poly, POINT2D *pt_outside)
+{	
+	/* Make sure we have boxes */
+	if ( poly->bbox )
+	{
+		gbox_pt_outside(poly->bbox, pt_outside);
+		return;
+	}
+	else
+	{
+		GBOX gbox;
+		lwgeom_calculate_gbox_geodetic((LWGEOM*)poly, &gbox);
+		gbox_pt_outside(&gbox, pt_outside);
+		return;
+	}
+}
 
 /**
 * Given a unit geocentric gbox, return a lon/lat (degrees) coordinate point point that is
@@ -1814,6 +1829,7 @@ static double ptarray_distance_spheroid(const POINTARRAY *pa1, const POINTARRAY
 			}
 			e1.start = e1.end;
 		}
+
 		/* On sphere, return answer */
 		if ( use_sphere )
 			return distance;
@@ -2465,6 +2481,7 @@ int ptarray_calculate_gbox_geodetic(const POINTARRAY *pa, GBOX *gbox)
 	assert(gbox);
 	assert(pa);
 
+	gbox_init(&edge_gbox);
 	edge_gbox.flags = gbox->flags;
 
 	if ( pa->npoints == 0 ) return LW_FAILURE;
@@ -3078,7 +3095,7 @@ dot_product_side(const POINT3D *p, const POINT3D *q)
 int 
 edge_intersects(const POINT3D *A1, const POINT3D *A2, const POINT3D *B1, const POINT3D *B2)
 {
-	POINT3D AN, BN;  /* Normals to plane A and plane B */
+	POINT3D AN, BN, VN;  /* Normals to plane A and plane B */
 	double ab_dot;
 	int a1_side, a2_side, b1_side, b2_side;
 	int rv = PIR_NO_INTERACT;
@@ -3126,8 +3143,21 @@ edge_intersects(const POINT3D *A1, const POINT3D *A2, const POINT3D *B1, const P
 	if ( a1_side != a2_side && (a1_side + a2_side) == 0 &&
 	     b1_side != b2_side && (b1_side + b2_side) == 0 )
 	{
-		/* Mid-point intersection! */
-		return PIR_INTERSECTS;
+		/* Have to check if intersection point is inside both arcs */
+		unit_normal(&AN, &BN, &VN);
+		if ( point_in_cone(A1, A2, &VN) && point_in_cone(B1, B2, &VN) )
+		{
+			return PIR_INTERSECTS;
+		}
+
+		/* Have to check if intersection point is inside both arcs */
+		vector_scale(&VN, -1);
+		if ( point_in_cone(A1, A2, &VN) && point_in_cone(B1, B2, &VN) )
+		{
+			return PIR_INTERSECTS;
+		}
+		
+		return PIR_NO_INTERACT;
 	}
 
 	/* The rest are all intersects variants... */
