@@ -1,8 +1,8 @@
 /**********************************************************************
- * $Id: pgsql2shp-core.h 9324 2012-02-27 22:08:12Z pramsey $
+ * $Id: pgsql2shp-core.h 13134 2014-12-01 08:47:21Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
- * http://postgis.refractions.net
+ * http://postgis.net
  * Copyright 2001-2003 Refractions Research Inc.
  * Copyright 2009 Paul Ramsey <pramsey@cleverelephant.ca>
  * Copyright 2009 Mark Cave-Ayland <mark.cave-ayland@siriusit.co.uk>
@@ -29,7 +29,7 @@
 #include "shpcommon.h"
 #include "getopt.h"
 
-#define P2S_RCSID "$Id: pgsql2shp-core.h 9324 2012-02-27 22:08:12Z pramsey $"
+#define P2S_RCSID "$Id: pgsql2shp-core.h 13134 2014-12-01 08:47:21Z strk $"
 
 
 /*
