@@ -1,8 +1,8 @@
 /**********************************************************************
- * $Id: shp2pgsql-core.h 9548 2012-03-26 16:23:58Z mcayland $
+ * $Id: shp2pgsql-core.h 13134 2014-12-01 08:47:21Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
- * http://postgis.refractions.net
+ * http://postgis.net
  * Copyright 2001-2003 Refractions Research Inc.
  * Copyright 2009 Paul Ramsey <pramsey@cleverelephant.ca>
  * Copyright 2009 Mark Cave-Ayland <mark.cave-ayland@siriusit.co.uk>
@@ -29,7 +29,7 @@
 
 #include "../liblwgeom/stringbuffer.h"
 
-#define S2P_RCSID "$Id: shp2pgsql-core.h 9548 2012-03-26 16:23:58Z mcayland $"
+#define S2P_RCSID "$Id: shp2pgsql-core.h 13134 2014-12-01 08:47:21Z strk $"
 
 
 /* Number of digits of precision in WKT produced. */
